@@ -17,9 +17,10 @@ from base.axe_base import AxeBase
 from base.axe_x_base import AxeXBase, calculer_axe_x_base
 from base.can_base import CANBase
 from plot.plot_base import tracer
+import base.constantes_base as cst
 
 class Signal4TNS(Signal3Mesure):
-    def sous_echantillonner(self, P, nom = ""):
+    def __sous_echantillonner(self, P, nom = ""):
         axe_x_base_entree = self._PlotBase__lire_axe_x_base()
         liste_xmin_xmax = axe_x_base_entree.calculer_liste_xmin_xmax()
         Xe_entree = axe_x_base_entree.lire_Xe()
@@ -40,7 +41,7 @@ class Signal4TNS(Signal3Mesure):
             sortie._Signal1Base__nom = nom
         return sortie
 
-    def sur_echantillonner(self, P, nom = ""):
+    def __sur_echantillonner(self, P, nom = ""):
         axe_x_base_entree = self._PlotBase__lire_axe_x_base()
         NTa = axe_x_base_entree.NXa
         assert NTa % P == 0, "Impossible de suréchantilloner. La période d'échantillonnage finale doit être multiple de {0} s".format(10**-axe_x_base_entree.Pa)
@@ -63,21 +64,47 @@ class Signal4TNS(Signal3Mesure):
             sortie._Signal1Base__nom = self.lire_nom() + "_sur_échantillonné_{0}".format(P)
         else:
             sortie._Signal1Base__nom = nom
+
         return sortie
 
-    def echantillonner(self, Xe, nom = ""):
-        assert self._PlotBase__lire_axe_x_base().NXa == 1, 'Le signal d\'entrée doit être "analogique"'        
-        axe_x_base_sortie = AxeXBase(self._PlotBase__lire_axe_x_base().calculer_liste_xmin_xmax(), Xe)        
-        P = axe_x_base_sortie.NXa
-        sortie = self.sous_echantillonner(P).sur_echantillonner(P)
+    def echantillonner(self, Te, nom = ""):
+        axe_x_base_entree = self._PlotBase__lire_axe_x_base()
+        
+        assert axe_x_base_entree.lire_Xe() == cst.Xe, "echantillonner: le signal ne doit pas avoir été échantillonné auparavant"
+        can_base = self.__lire_can_base()
+        assert can_base.NXe == None, "echantillonner: le signal ne doit pas avoir été échantillonné auparavant"
+        
+        axe_x_base_sortie = AxeXBase(self._PlotBase__lire_axe_x_base().calculer_liste_xmin_xmax(), Te)        
+        assert  axe_x_base_sortie.NXa %  axe_x_base_entree.NXa == 0, "echantillonner: Te doit être un multiple de {0} s".format(cst.Xe)
+
+        P = axe_x_base_sortie.NXa //  axe_x_base_entree.NXa
+        sortie = self.__sous_echantillonner(P).__sur_echantillonner(P)
         if nom == "":
             sortie._Signal1Base__nom = self.lire_nom() + "_échantillonné"
         else:
             sortie._Signal1Base__nom = nom
+
+        can_base = sortie.__lire_can_base()
+        can_base.NXe = P
+        can_base.test_ech = True
+
         return sortie
 
+    def bloquer(self, alpha = 1, nom = ""):
+        can_base = self.__lire_can_base()
+        assert can_base.test_ech == True, "bloquer: le signal doit avoir été échantillonné pour pouvoir être bloqué"
 
-    def bloquer(self, P, nom = ""):
+        assert 0 < alpha <= 1, "bloquer: le ration de blocage est compris entre 0 (pas de blocage) et 1 (blocage sur toute la période d'échantillonnage)"
+        NXe = can_base.NXe
+        P = int(np.round(alpha*NXe))
+        P = max(1, P)
+        P = min(NXe, P)
+        sortie = self.__bloquer(P, nom)
+        can_base = sortie.__lire_can_base()
+        can_base.test_ech = False
+        return sortie
+        
+    def __bloquer(self, P, nom = ""):
         vecteur_y = self.lire_vecteur_y()
         N = len(vecteur_y)
 
@@ -88,12 +115,25 @@ class Signal4TNS(Signal3Mesure):
         sortie._Signal1Base__vecteur_y = vecteur_y
         
         if nom == "":
-            sortie._Signal1Base__nom = self.lire_nom() + "_bloqué_{0}".format(P)
+            sortie._Signal1Base__nom = self.lire_nom() + "_bloqué" #_{0}".format(P)
         else:
             sortie._Signal1Base__nom = nom
         return sortie
 
-    def extrapoler(self, P, nom = ""):
+    def extrapoler(self, nom = ""):
+        can_base = self.__lire_can_base()
+        assert can_base.test_ech == True, "bloquer: le signal doit avoir été échantillonné pour pouvoir être extrapolé"
+
+        P = can_base.NXe
+        sortie = self.__extrapoler(P, nom)
+
+        can_base = sortie.__lire_can_base()
+        can_base.test_ech = False
+
+        return sortie
+
+
+    def __extrapoler(self, P, nom = ""):
         vecteur_y = self.lire_vecteur_y()
         N = len(vecteur_y)
 
@@ -104,7 +144,7 @@ class Signal4TNS(Signal3Mesure):
         sortie._Signal1Base__vecteur_y = vecteur_y
         
         if nom == "":
-            sortie._Signal1Base__nom = self.lire_nom() + "_extrapolé_{0}".format(P)
+            sortie._Signal1Base__nom = self.lire_nom() + "_extrapolé" # _{0}".format(P)
         else:
             sortie._Signal1Base__nom = nom
         return sortie
@@ -113,7 +153,7 @@ class Signal4TNS(Signal3Mesure):
     def quantifier(self, Pbits = 8, liste_umin_umax=[-10., 10.], nom = ""):
         sortie = self.__convertir_analogique_vers_numerique(Pbits, liste_umin_umax).__convertir_numerique_vers_analogique()
         if nom == "":
-            sortie._Signal1Base__nom = self.lire_nom() + "_quantifié_{0}".format(Pbits)
+            sortie._Signal1Base__nom = self.lire_nom() + "_quantifié" #_{0}".format(Pbits)
         else:
             sortie._Signal1Base__nom = nom
         return sortie
@@ -136,6 +176,19 @@ class Signal4TNS(Signal3Mesure):
             sortie._Signal1Base__nom = nom
         return sortie
 
+    def __convertir_vecteur_numerique_vers_analogique(self):
+        can_base = self.__lire_can_base()
+
+        Pbits = can_base.Pbits
+        liste_umin_umax = can_base.liste_umin_umax 
+        
+        assert Pbits != None and liste_umin_umax !=None, "__convertir_numerique_vers_analogique: le signal n'est pas numérique"
+
+        vecteur_y = self.lire_vecteur_y()
+        umin, umax = liste_umin_umax
+        vecteur_y =   (vecteur_y+0.5) * (umax - umin) / 2**Pbits + (umax+umin) / 2
+        return vecteur_y
+
     def __convertir_numerique_vers_analogique(self, nom = ""):
         can_base = self.__lire_can_base()
 
@@ -145,10 +198,8 @@ class Signal4TNS(Signal3Mesure):
         assert Pbits != None and liste_umin_umax !=None, "__convertir_numerique_vers_analogique: le signal n'est pas numérique"
 
         sortie = self.copier()
-        vecteur_y = sortie.lire_vecteur_y()
-        umin, umax = liste_umin_umax
-        vecteur_y =   (vecteur_y+0.5) * (umax - umin) / 2**Pbits + (umax+umin) / 2
-        sortie._Signal1Base__vecteur_y = vecteur_y
+        sortie._Signal1Base__vecteur_y = sortie.__convertir_vecteur_numerique_vers_analogique()
+
         if nom == "":
             sortie._Signal1Base__nom = self.lire_nom() + "_cna"
         else:
@@ -240,16 +291,20 @@ if __name__ == "__main__":
     s1 = Signal4TNS(bdt, vecteur_y)
     P = 4
     s1 = s1 + 1
-    
-    s2 = s1.calculer_fft()
-    s3 = s2.calculer_ifft()
-    s4 = s1.calculer_spectre()
-    s3 = s2.calculer_ifft()
-    s5 = s1.echantillonner(1e-4)
-    s6 = s1.quantifier(8, [-10, 10])
-    # tracer(s1, s4, s2, s3, s5, s6, superposition=False)
 
-    print(s6._Signal4TNS__lire_can_base().liste_umin_umax)
+    s2 = s1.echantillonner(1e-5).bloquer(0.9).quantifier(6, [-1, 3])
+    tracer(s1, s2, superposition = True)
+    can_base = s2._Signal4TNS__lire_can_base()
+    print(can_base.NXe)
+    # s2 = s1.calculer_fft()
+    # s3 = s2.calculer_ifft()
+    # s4 = s1.calculer_spectre()
+    # s3 = s2.calculer_ifft()
+    # s5 = s1.echantillonner(1e-4)
+    # s6 = s1.quantifier(8, [-10, 10])
+    # # tracer(s1, s4, s2, s3, s5, s6, superposition=False)
+
+    # print(s6._Signal4TNS__lire_can_base().liste_umin_umax)
     # bdt1 =s1._PlotBase__lire_axe_x_base()
     # bdt2 =s2._PlotBase__lire_axe_x_base()
     
