@@ -20,6 +20,8 @@ from signaux.signal_4_tns import Signal4TNS
 from base.axe_x_base import AxeXBase
 from plot.plot_base import tracer
 
+import base.constantes_base as cst
+
 class Signal5Wav(Signal4TNS):
     def lire_wav(self, nom_fichier, Pbits = 16, liste_umin_max = [-10, 10]):
         Fe, data = wave.read(nom_fichier)
@@ -61,14 +63,22 @@ class Signal5Wav(Signal4TNS):
 
     def __mettre_en_forme_wav(self):
         can_base = self._Signal4TNS__lire_can_base()
-        assert can_base.Pbits != None, "__mettre_en_forme_wav: le signal n'est pas quantifié"
-        assert can_base.Pbits <= 16, "__mettre_en_forme_wav: le signal est quantifié sur plus de 16 bits"
-        Fe = 1/self._PlotBase__lire_axe_x_base().lire_Xe()
+        assert can_base.Pbits == None or can_base.Pbits <= 16, "__mettre_en_forme_wav: le signal est quantifié sur plus de 16 bits"
 
+        if can_base.NXe != None:
+            sortie = self._Signal4TNS__sous_echantillonner(can_base.NXe)
+        else:
+            sortie = self.copier()
+
+        Fe = 1/sortie._PlotBase__lire_axe_x_base().lire_Xe()
         assert Fe <= 50000, "__mettre_en_forme_wav: le signal est échantillonné à plus de 50kHz"
-        can_base = self._Signal4TNS__lire_can_base()
-        # sortie = self._Signal4TNS__convertir_numerique_vers_analogique()._Signal4TNS__convertir_analogique_vers_numerique(16, can_base.liste_umin_umax)
-        sortie = self._Signal4TNS__convertir_analogique_vers_numerique(16, can_base.liste_umin_umax)
+
+        can_base = sortie._Signal4TNS__lire_can_base()
+        if can_base.Pbits == None:
+            can_base.Pbits = cst.Pbits
+            can_base.liste_umin_umax = cst.liste_umin_umax
+
+        sortie = sortie._Signal4TNS__convertir_analogique_vers_numerique(16, can_base.liste_umin_umax)
         vecteur_y = sortie._Signal1Base__vecteur_y
         sortie._Signal1Base__vecteur_y = vecteur_y.astype(np.int16)
         return sortie
@@ -84,7 +94,7 @@ if __name__ == "__main__":
     # bdt = s1._PlotBase__lire_axe_x_base()
     # Xe = bdt.lire_Xe()
 
-    # s2 = s1.sous_echantillonner(100)
+    # s2 = s1.__sous_echantillonner(100)
     # s2.enregistrer_wav("/Users/nicolas/tmp/test.wav")
 
     # axe_x_base2 = s2._PlotBase__lire_axe_x_base()
@@ -98,18 +108,17 @@ if __name__ == "__main__":
 
     # s2.plot()
     # plt.show()
-    Fe =20e3
-    F1 = 1000
-    F2 = Fe-F1
+    Fe = 50e3
+    Te = 1/Fe
+    F = 440
+
+    axe_x_base = AxeXBase([0, 1], Te)
+    vecteur_t = axe_x_base.lire_vecteur_x()
+    vecteur_s = np.sin(2*np.pi*F*vecteur_t)
+
+    s = Signal5Wav(axe_x_base, vecteur_s)
 
-    Xe = 1/Fe
-    bdt = AxeXBase([0, 1], Xe)
-    vt = bdt.lire_vecteur_x()
-    vs1 = np.sin(2*np.pi*F1*vt)
-    vs2 = np.sin(2*np.pi*F2*vt)
-    s1 = Signal5Wav(bdt, vs1)#.numeriser(Xe, 16, [-10, 10])
-    s2 = Signal5Wav(bdt, vs2)#.numeriser(Xe, 16, [-10, 10])
     # s1.enregistrer_wav("/Users/nicolas/tmp/test.wav")
-    # s1.ecouter_wav()#"/Users/nicolas/tmp/test.wav")
+    s.ecouter_wav()#"/Users/nicolas/tmp/test.wav")
 
-    tracer(s1, s2)
+    
\ No newline at end of file
