@@ -37,10 +37,10 @@ class Sysam2Mode(Sysam1Base):
         test_synchrone = False
         if not test_trigger and test_entree and test_sortie:
             if self.liste_entrees_simples: 
-                if self.liste_entrees_simples[0].lire_base_de_temps().lire_iemin() == 0:
+                if self.liste_entrees_simples[0]._PlotBase__lire_axe_x_base().iemin == 0:
                     test_synchrone = True
             if self.liste_entrees_diffs: 
-                if self.liste_entrees_diffs[0].lire_base_de_temps().lire_iemin() == 0:
+                if self.liste_entrees_diffs[0]._PlotBase__lire_axe_x_base().iemin == 0:
                     test_synchrone = True
 
         chaine_mode = ""
